==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d8/da8/tunnelbridge__cmd_8cpp.js <==
var tunnelbridge__cmd_8cpp =
[
    [ "CalcBridgeLenCostFactor", "d8/da8/tunnelbridge__cmd_8cpp.html#ae829da59ab995ded5c6498a2d3295f5b", null ],
    [ "CalcBridgePiece", "d8/da8/tunnelbridge__cmd_8cpp.html#a2362eb088c8ef8c023a1e98a04bf0a85", null ],
    [ "ChangeTileOwner_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a6f812508fed6246c047d0dea6ad23619", null ],
    [ "CheckAllowRemoveTunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a2de61dd8d479235421fad4b8a7385f38", null ],
    [ "CheckBridgeAvailability", "d8/da8/tunnelbridge__cmd_8cpp.html#aa2161ce0aa5558a25f9483362b4fe3ba", null ],
    [ "CheckBridgeSlope", "d8/da8/tunnelbridge__cmd_8cpp.html#a2248e0062b3d66baadd94c3cf87a62a2", null ],
    [ "ClearTile_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#ac077082052e7dd8d72364f2208cba9bc", null ],
    [ "CmdBuildBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a93a509839c6475ff4af9fbf56ecfdce0", null ],
    [ "CmdBuildTunnel", "d8/da8/tunnelbridge__cmd_8cpp.html#a111dbc99de08b96c5f6f0bb838f21206", null ],
    [ "DoClearBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a2e70340720223905fe324baee6e12c9a", null ],
    [ "DoClearTunnel", "d8/da8/tunnelbridge__cmd_8cpp.html#ace9f85c3104283fe74adc2418e3d60a0", null ],
    [ "DrawBridgeMiddle", "d8/da8/tunnelbridge__cmd_8cpp.html#a3c04bab456b15ce6678b646f897dbbfe", null ],
    [ "DrawBridgePillars", "d8/da8/tunnelbridge__cmd_8cpp.html#af8ca5203b14318befce42de2c0c8de66", null ],
    [ "DrawBridgeTramBits", "d8/da8/tunnelbridge__cmd_8cpp.html#a4877e77715d82f2ed4c7eee9679bfded", null ],
    [ "DrawPillar", "d8/da8/tunnelbridge__cmd_8cpp.html#af043dc64b8e3fd3e148ede4d6a20d9ae", null ],
    [ "DrawPillarColumn", "d8/da8/tunnelbridge__cmd_8cpp.html#a6dae3806996aae54a4a2220166f20304", null ],
    [ "DrawTile_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#ab45776b3d816f79a7f2cc3c592ea65f5", null ],
    [ "GetBridgeFoundation", "d8/da8/tunnelbridge__cmd_8cpp.html#a4c471316153700ba2d5748f009731470", null ],
    [ "GetBridgeSpriteTable", "d8/da8/tunnelbridge__cmd_8cpp.html#a2123672310a6a38880a41467863cd5e1", null ],
    [ "GetFoundation_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a0877fd176e8993d09d0527ab3ac71566", null ],
    [ "GetSlopePixelZ_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#aaaffb09fbecfe736e61e10fb04ba6ff7", null ],
    [ "GetTileDesc_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a041fcfb32ab76716f03d38e356e30ed8", null ],
    [ "GetTileTrackStatus_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#aa3e40d1482801067804a108401af53d4", null ],
    [ "HasBridgeFlatRamp", "d8/da8/tunnelbridge__cmd_8cpp.html#aa3711e2411d2eec45064f4551c2a48ff", null ],
    [ "MarkBridgeDirty", "d8/da8/tunnelbridge__cmd_8cpp.html#a9b6b362c8c53ca5a331273a187ace5b5", null ],
    [ "MarkBridgeDirty", "d8/da8/tunnelbridge__cmd_8cpp.html#a7c197a49a3a59cecf047d99780e50394", null ],
    [ "ResetBridges", "d8/da8/tunnelbridge__cmd_8cpp.html#af4941c70f6691de70f5d525caecd3bcd", null ],
    [ "TerraformTile_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#af6effa39b237f98c2d3d83040b26945a", null ],
    [ "TileLoop_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#af645f23de1f1d0a94e724bed0d8356f4", null ],
    [ "VehicleEnter_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a163d53477c656547c33aac2889dd88b6", null ],
    [ "_bridge", "d8/da8/tunnelbridge__cmd_8cpp.html#ad970e2f06de996dbd07fe782edc77a4b", null ],
    [ "_build_tunnel_endtile", "d8/da8/tunnelbridge__cmd_8cpp.html#ad67734da3d841b9aee742bdd7eb0850d", null ],
    [ "_tile_type_tunnelbridge_procs", "d8/da8/tunnelbridge__cmd_8cpp.html#a77ae6f1727ad83a9598544ccf846061e", null ],
    [ "_tunnel_visibility_frame", "d8/da8/tunnelbridge__cmd_8cpp.html#a42613a61a30ff81a8c4c461821f16ca0", null ],
    [ "BRIDGE_Z_START", "d8/da8/tunnelbridge__cmd_8cpp.html#acb2a2483938c0fc7313941db0d8d34e1", null ],
    [ "TUNNEL_SOUND_FRAME", "d8/da8/tunnelbridge__cmd_8cpp.html#a4f46e114735baff86ca461d420a73482", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d8/da8/tunnelbridge__cmd_8cpp.js <==
var tunnelbridge__cmd_8cpp =
[
    [ "CalcBridgeLenCostFactor", "d8/da8/tunnelbridge__cmd_8cpp.html#ae829da59ab995ded5c6498a2d3295f5b", null ],
    [ "CalcBridgePiece", "d8/da8/tunnelbridge__cmd_8cpp.html#a2362eb088c8ef8c023a1e98a04bf0a85", null ],
    [ "ChangeTileOwner_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a6f812508fed6246c047d0dea6ad23619", null ],
    [ "CheckAllowRemoveTunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a2de61dd8d479235421fad4b8a7385f38", null ],
    [ "CheckBridgeAvailability", "d8/da8/tunnelbridge__cmd_8cpp.html#aa2161ce0aa5558a25f9483362b4fe3ba", null ],
    [ "CheckBridgeSlope", "d8/da8/tunnelbridge__cmd_8cpp.html#a2248e0062b3d66baadd94c3cf87a62a2", null ],
    [ "ClearTile_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#ac077082052e7dd8d72364f2208cba9bc", null ],
    [ "CmdBuildBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a93a509839c6475ff4af9fbf56ecfdce0", null ],
    [ "CmdBuildTunnel", "d8/da8/tunnelbridge__cmd_8cpp.html#a111dbc99de08b96c5f6f0bb838f21206", null ],
    [ "DoClearBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a2e70340720223905fe324baee6e12c9a", null ],
    [ "DoClearTunnel", "d8/da8/tunnelbridge__cmd_8cpp.html#ace9f85c3104283fe74adc2418e3d60a0", null ],
    [ "DrawBridgeMiddle", "d8/da8/tunnelbridge__cmd_8cpp.html#a3c04bab456b15ce6678b646f897dbbfe", null ],
    [ "DrawBridgePillars", "d8/da8/tunnelbridge__cmd_8cpp.html#af8ca5203b14318befce42de2c0c8de66", null ],
    [ "DrawBridgeRoadBits", "d8/da8/tunnelbridge__cmd_8cpp.html#a558ca622cc827a7f7b56abeacbbdbfde", null ],
    [ "DrawPillar", "d8/da8/tunnelbridge__cmd_8cpp.html#af043dc64b8e3fd3e148ede4d6a20d9ae", null ],
    [ "DrawPillarColumn", "d8/da8/tunnelbridge__cmd_8cpp.html#a6dae3806996aae54a4a2220166f20304", null ],
    [ "DrawTile_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#ab45776b3d816f79a7f2cc3c592ea65f5", null ],
    [ "GetBridgeFoundation", "d8/da8/tunnelbridge__cmd_8cpp.html#a4c471316153700ba2d5748f009731470", null ],
    [ "GetBridgeRoadCatenary", "d8/da8/tunnelbridge__cmd_8cpp.html#ae12f79cd048d5e0ccce6752230a4ec95", null ],
    [ "GetBridgeSpriteTable", "d8/da8/tunnelbridge__cmd_8cpp.html#a2123672310a6a38880a41467863cd5e1", null ],
    [ "GetFoundation_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a0877fd176e8993d09d0527ab3ac71566", null ],
    [ "GetSlopePixelZ_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#aaaffb09fbecfe736e61e10fb04ba6ff7", null ],
    [ "GetTileDesc_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a041fcfb32ab76716f03d38e356e30ed8", null ],
    [ "GetTileTrackStatus_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#aa3e40d1482801067804a108401af53d4", null ],
    [ "HasBridgeFlatRamp", "d8/da8/tunnelbridge__cmd_8cpp.html#aa3711e2411d2eec45064f4551c2a48ff", null ],
    [ "MarkBridgeDirty", "d8/da8/tunnelbridge__cmd_8cpp.html#a9b6b362c8c53ca5a331273a187ace5b5", null ],
    [ "MarkBridgeDirty", "d8/da8/tunnelbridge__cmd_8cpp.html#a7c197a49a3a59cecf047d99780e50394", null ],
    [ "ResetBridges", "d8/da8/tunnelbridge__cmd_8cpp.html#af4941c70f6691de70f5d525caecd3bcd", null ],
    [ "TerraformTile_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#af6effa39b237f98c2d3d83040b26945a", null ],
    [ "TileLoop_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#af645f23de1f1d0a94e724bed0d8356f4", null ],
    [ "TunnelBridgeClearCost", "d8/da8/tunnelbridge__cmd_8cpp.html#a33fdcb9916ca41b5a084552f23432d46", null ],
    [ "VehicleEnter_TunnelBridge", "d8/da8/tunnelbridge__cmd_8cpp.html#a163d53477c656547c33aac2889dd88b6", null ],
    [ "_bridge", "d8/da8/tunnelbridge__cmd_8cpp.html#ad970e2f06de996dbd07fe782edc77a4b", null ],
    [ "_build_tunnel_endtile", "d8/da8/tunnelbridge__cmd_8cpp.html#ad67734da3d841b9aee742bdd7eb0850d", null ],
    [ "_tile_type_tunnelbridge_procs", "d8/da8/tunnelbridge__cmd_8cpp.html#a77ae6f1727ad83a9598544ccf846061e", null ],
    [ "_tunnel_visibility_frame", "d8/da8/tunnelbridge__cmd_8cpp.html#a42613a61a30ff81a8c4c461821f16ca0", null ],
    [ "BRIDGE_Z_START", "d8/da8/tunnelbridge__cmd_8cpp.html#acb2a2483938c0fc7313941db0d8d34e1", null ],
    [ "TUNNEL_SOUND_FRAME", "d8/da8/tunnelbridge__cmd_8cpp.html#a4f46e114735baff86ca461d420a73482", null ]
];
